==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1NamespaceSpecFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public class V1NamespaceSpecFluentImpl<A extends V1NamespaceSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1NamespaceSpecFluent<A>{

    private List<String> finalizers;

    public V1NamespaceSpecFluentImpl(){
    }
    public V1NamespaceSpecFluentImpl(V1NamespaceSpec instance){
            this.withFinalizers(instance.getFinalizers());

    }

    public A addToFinalizers(int index,String item){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            this.finalizers.add(index, item);
            return (A)this;
    }

    public A setToFinalizers(int index,String item){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            this.finalizers.set(index, item); return (A)this;
    }

    public A addToFinalizers(String... items){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            for (String item : items) {this.finalizers.add(item);} return (A)this;
    }

    public A addAllToFinalizers(Collection<String> items){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            for (String item : items) {this.finalizers.add(item);} return (A)this;
    }

    public A removeFromFinalizers(String... items){
            for (String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
    }

    public A removeAllFromFinalizers(Collection<String> items){
            for (String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
    }

    public List<String> getFinalizers(){
            return this.finalizers;
    }

    public String getFinalizer(int index){
            return this.finalizers.get(index);
    }

    public String getFirstFinalizer(){
            return this.finalizers.get(0);
    }

    public String getLastFinalizer(){
            return this.finalizers.get(finalizers.size() - 1);
    }

    public String getMatchingFinalizer(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: finalizers) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withFinalizers(List<String> finalizers){
            if (this.finalizers != null) { _visitables.removeAll(this.finalizers);}
            if (finalizers != null) {this.finalizers = new ArrayList<String>(); for (String item : finalizers){this.addToFinalizers(item);}} else { this.finalizers = null;} return (A) this;
    }

    public A withFinalizers(String... finalizers){
            if (this.finalizers != null) {this.finalizers.clear();}
            if (finalizers != null) {for (String item :finalizers){ this.addToFinalizers(item);}} return (A) this;
    }

    public Boolean hasFinalizers(){
            return finalizers != null && !finalizers.isEmpty();
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1NamespaceSpecFluentImpl that = (V1NamespaceSpecFluentImpl) o;
            if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NamespaceSpecFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1NamespaceSpecFluentImpl<A extends V1NamespaceSpecFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1NamespaceSpecFluent<A>{

    private List<String> finalizers;

    public V1NamespaceSpecFluentImpl(){
    }
    public V1NamespaceSpecFluentImpl(V1NamespaceSpec instance){
            this.withFinalizers(instance.getFinalizers());

    }

    public A addToFinalizers(int index,String item){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            this.finalizers.add(index, item);
            return (A)this;
    }

    public A setToFinalizers(int index,String item){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            this.finalizers.set(index, item); return (A)this;
    }

    public A addToFinalizers(String... items){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            for (String item : items) {this.finalizers.add(item);} return (A)this;
    }

    public A addAllToFinalizers(Collection<String> items){
            if (this.finalizers == null) {this.finalizers = new ArrayList<String>();}
            for (String item : items) {this.finalizers.add(item);} return (A)this;
    }

    public A removeFromFinalizers(String... items){
            for (String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
    }

    public A removeAllFromFinalizers(Collection<String> items){
            for (String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
    }

    public List<String> getFinalizers(){
            return this.finalizers;
    }

    public String getFinalizer(int index){
            return this.finalizers.get(index);
    }

    public String getFirstFinalizer(){
            return this.finalizers.get(0);
    }

    public String getLastFinalizer(){
            return this.finalizers.get(finalizers.size() - 1);
    }

    public String getMatchingFinalizer(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: finalizers) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingFinalizer(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: finalizers) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withFinalizers(List<String> finalizers){
            if (this.finalizers != null) { _visitables.get("finalizers").removeAll(this.finalizers);}
            if (finalizers != null) {this.finalizers = new ArrayList<String>(); for (String item : finalizers){this.addToFinalizers(item);}} else { this.finalizers = null;} return (A) this;
    }

    public A withFinalizers(String... finalizers){
            if (this.finalizers != null) {this.finalizers.clear();}
            if (finalizers != null) {for (String item :finalizers){ this.addToFinalizers(item);}} return (A) this;
    }

    public Boolean hasFinalizers(){
            return finalizers != null && !finalizers.isEmpty();
    }

    public A addNewFinalizer(String arg1){
            return (A)addToFinalizers(new String(arg1));
    }

    public A addNewFinalizer(StringBuilder arg1){
            return (A)addToFinalizers(new String(arg1));
    }

    public A addNewFinalizer(StringBuffer arg1){
            return (A)addToFinalizers(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1NamespaceSpecFluentImpl that = (V1NamespaceSpecFluentImpl) o;
            if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
            return true;
    }




}
